/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: Disc.java,v 1.2 2004/02/01 04:17:45 christianc Exp $
 */
package org.enhydra.barracuda.discRack.biz.disc;

import org.enhydra.barracuda.discRack.biz.DiscRackBusinessException;
import org.enhydra.barracuda.discRack.biz.person.Person;
import org.enhydra.barracuda.discRack.data.person.PersonDO;
import org.enhydra.barracuda.discRack.data.disc.DiscDO;
import com.lutris.appserver.server.sql.DatabaseManagerException;
import com.lutris.appserver.server.sql.ObjectIdException;
import com.lutris.dods.builder.generator.query.DataObjectException;

/**
 * Represents a disc.
 */
public class Disc {
    /**
     * The DO of the disc.
     */
    protected DiscDO myDO = null;

    /**
     * The public constructor.
     */
    public Disc() throws DiscRackBusinessException {
        try {
            this.myDO = DiscDO.createVirgin();
        } catch(DatabaseManagerException ex) {
            throw new DiscRackBusinessException("Error creating empty Disc", ex);
        } catch(ObjectIdException ex) {
            throw new DiscRackBusinessException("Error creating empty Disc", ex);
        }
    }

    /** The protected constructor
     *
     * @param theDisc. The data object of the disc.
     */
    protected Disc(DiscDO theDisc)
        throws DiscRackBusinessException  {
        this.myDO = theDisc;
    }

    /**
     * Gets the object id for the disc
     *
     * @return the object id.
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public String getHandle()
        throws DiscRackBusinessException {
        try {
            return this.myDO.getHandle();
        } catch(DatabaseManagerException ex) {
            throw new DiscRackBusinessException("Error getting disc's handle", ex);
        }
    }

    /**
     * Gets the title for the disc
     *
     * @return the title.
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public String getTitle()
        throws DiscRackBusinessException {
        try {
            return myDO.getTitle();
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error getting disc's title", ex);
        }
    }

    /**
     * Gets the artist for the disc
     *
     * @return the artist.
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public String getArtist()
        throws DiscRackBusinessException {
        try {
            return myDO.getArtist();
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error getting disc's artist", ex);
        }
    }

    /**
     * Gets the genre for the disc
     *
     * @return the genre.
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public String getGenre()
        throws DiscRackBusinessException {
        try {
            return myDO.getGenre();
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error getting disc's genre", ex);
        }
    }

    /**
     * Gets the preference for the disc
     *
     * @return true if like the disc, false if not
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public boolean isLiked()
        throws DiscRackBusinessException {
        try {
            return myDO.getIsLiked();
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error getting disc's likedness", ex);
        }
    }

    /**
     * Sets the title for the disc.
     *
     * @param the title.
     * @exception DiscRackBusinessException if an error occurs
     *   setting the data (usually due to an underlying data layer
     *   error).
     */
    public void setTitle(String title)
        throws DiscRackBusinessException {
        try {
            this.myDO .setTitle(title);
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error setting disc's title", ex);
        }
    }

    /**
     * Sets the artist for the disc.
     *
     * @param the artist.
     * @exception DiscRackBusinessException if an error occurs
     *   setting the data (usually due to an underlying data layer
     *   error).
     */
    public void setArtist(String artist)
        throws DiscRackBusinessException {
        try {
            this.myDO.setArtist(artist);
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error setting disc's artist", ex);
        }
    }

    /**
     * Sets the genre for the disc.
     *
     * @param the genre.
     * @exception DiscRackBusinessException if an error occurs
     *   setting the data (usually due to an underlying data layer
     *   error).
     */
    public void setGenre(String genre)
        throws DiscRackBusinessException {
        try {
            this.myDO.setGenre(genre);
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error setting disc's genre", ex);
        }
    }

    /**
     * Sets the owner for the disc.
     *
     * @param the owner.
     * @exception DiscRackBusinessException if an error occurs
     *   setting the data (usually due to an underlying data layer
     *   error).
     */
    public void setOwner(Person owner)
        throws DiscRackBusinessException
    {
        try {
            this.myDO.setOwner(PersonDO.createExisting(owner.getHandle()));
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error setting disc's owner", ex);
        }
    }

    /**
     * Sets the preference for the disc.
     *
     * @param the preference.
     * @exception DiscRackBusinessException if an error occurs
     *   setting the data (usually due to an underlying data layer
     *   error).
     */
    public void setLiked(boolean isLiked)
        throws DiscRackBusinessException {
        try {
            this.myDO.setIsLiked(isLiked);
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error setting disc's likedness", ex);
        }
    }


    /**
     * Commits all changes to the database.
     *
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public void save()
        throws DiscRackBusinessException {
        try {
            this.myDO.commit();
        } catch(Exception ex) {
            throw new DiscRackBusinessException("Error saving disc", ex);
        }
    }

    /**
     * Deletes the disc from the database.
     *
     * @exception DiscRackBusinessException if an error occurs
     *   deleting data (usually due to an underlying data layer
     *   error).
     */
    public void delete()
        throws DiscRackBusinessException {
        try {
            this.myDO.delete();
        } catch(Exception ex) {
            throw new DiscRackBusinessException("Error deleting disc", ex);
        }
    }
}
