/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: DiscFactory.java,v 1.2 2004/02/01 04:17:45 christianc Exp $
 */
package org.enhydra.barracuda.discRack.biz.disc;

import org.enhydra.barracuda.discRack.biz.DiscRackBusinessException;
import org.enhydra.barracuda.discRack.data.disc.*;
import org.enhydra.barracuda.discRack.biz.person.Person;
import com.lutris.dods.builder.generator.query.*;
import org.enhydra.barracuda.discRack.biz.person.Person;
import org.enhydra.barracuda.discRack.data.person.PersonDO;
import com.lutris.appserver.server.sql.ObjectId;

/**
 * Used to find the instances of disc.
 */
public class DiscFactory {

    /**
     * The findDiscsForPerson method performs a database query to
     * return an array of <CODE>Disc</CODE> objects
     * representing all the rows in the <CODE>disc</CODE> table
     * that have and owner matching <CODE>Person owner</CODE>.
     *
     * @param owner. The owner of the discs
     * @return
     *     array of discs.
     * @exception DiscRackBusinessException
     *   If there is a problem retrieving disc information.
     */
    public static Disc[] findDiscsForPerson(Person owner)
        throws DiscRackBusinessException {
        Disc[] theDiscArray = null;

        try {
            DiscQuery query = new DiscQuery();
            //set query
            query.setQueryOwner(PersonDO.createExisting(owner.getHandle()));
            // Order discs alphabetically by artist
            query.addOrderByArtist();
            DiscDO[] DOarray = query.getDOArray();
            theDiscArray = new Disc[ DOarray.length ];
            for ( int i = 0; i < DOarray.length; i++ )
            theDiscArray[i] = new Disc(DOarray[i]);
        }catch(Exception ex) {
            throw new DiscRackBusinessException("Exception in findDiscsForPerson()", ex);
        }

        return theDiscArray;
    }

    /**
     * The findDiscByID method performs a database query to
     * return a <CODE>Disc</CODE> object
     * representing the row in the <CODE>disc</CODE> table
     * that matches the object id.
     *
     * @param id, the object id of the disc table.
     * @return
     *    the disc. null if there isn't a person associated
     *    the id
     * @exception DiscRackBusinessException
     *    if there is a problem retrieving person information.
     */
    public static Disc findDiscByID(String id)
        throws DiscRackBusinessException {
        Disc theDisc = null;

        try {
            DiscQuery query = new DiscQuery();
            //set query
            query.setQueryOId(new ObjectId(id));
            // Throw an exception if more than one user by this name is found
            query.requireUniqueInstance();
            DiscDO theDiscDO = query.getNextDO();
            theDisc = new Disc(theDiscDO);
            return theDisc;
        }catch(Exception ex) {
            throw new DiscRackBusinessException("Exception in findDiscsForPerson()", ex);
        }
    }
}

