/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: Person.java,v 1.2 2004/02/01 04:17:45 christianc Exp $
 */
package org.enhydra.barracuda.discRack.biz.person;

import org.enhydra.barracuda.discRack.biz.DiscRackBusinessException;
import org.enhydra.barracuda.discRack.data.person.*;
import org.enhydra.barracuda.discRack.data.disc.DiscDO;
import org.enhydra.barracuda.discRack.biz.disc.Disc;
import com.lutris.appserver.server.sql.DatabaseManagerException;
import com.lutris.appserver.server.sql.ObjectIdException;
import com.lutris.dods.builder.generator.query.DataObjectException;

/**
 * Represents a person.
 */
public class Person {
    /**
     * The DO of the Person.
     */
    protected PersonDO myDO = null;

    /**
     * The public constructor.
     */
    public Person() throws DiscRackBusinessException {
        try {
            this.myDO = PersonDO.createVirgin();
        } catch(DatabaseManagerException ex) {
            throw new DiscRackBusinessException("Error creating empty person", ex);
        } catch(ObjectIdException ex) {
            throw new DiscRackBusinessException("Error creating object ID for person", ex);
        }
    }

    /** The public constructor
     *
     * @param thePerson. The data object of the person.
     */
    public Person(PersonDO thePerson) {
        this.myDO = thePerson;
    }

    /**
     * Gets the object id for the person
     *
     * @return the object id.
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public String getHandle()
        throws DiscRackBusinessException {
        try {
            return this.myDO.getHandle();
        } catch(DatabaseManagerException ex) {
            throw new DiscRackBusinessException("Error getting handle for person", ex);
        }
    }

    /**
     * Gets the login name for the person
     *
     * @return the login name.
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public String getLogin()
        throws DiscRackBusinessException {
        try {
            return myDO.getLogin();
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error getting user's login name", ex);
        }
    }

    /**
     * Gets the password for the person
     *
     * @return the password.
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public String getPassword()
        throws DiscRackBusinessException {
        try {
            return myDO.getPassword();
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error getting user's password", ex);
        }
    }

    /**
     * Gets the firstname for the person
     *
     * @return the firstname.
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public String getFirstname()
        throws DiscRackBusinessException {
        try {
            return myDO.getFirstname();
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error getting user's first name", ex);
        }
    }

    /**
     * Gets the lastname for the person
     *
     * @return the lastname.
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public String getLastname()
        throws DiscRackBusinessException {
        try {
            return myDO.getLastname();
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error getting user's last name", ex);
        }
    }

    /**
     * Sets the login name for the person.
     *
     * @param the login name.
     * @exception DiscRackBusinessException if an error occurs
     *   setting the data (usually due to an underlying data layer
     *   error).
     */
    public void setLogin(String login)
        throws DiscRackBusinessException {
        try {
            myDO.setLogin(login);
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error setting user's login name", ex);
        }
    }

    /**
     * Sets the password for the person.
     *
     * @param the password.
     * @exception DiscRackBusinessException if an error occurs
     *   setting the data (usually due to an underlying data layer
     *   error).
     */
    public void setPassword(String password)
        throws DiscRackBusinessException {
        try {
            myDO.setPassword(password);
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error setting user's password", ex);
        }
    }

    /**
     * Sets the firstname for the person.
     *
     * @param the firstname.
     * @exception DiscRackBusinessException if an error occurs
     *   setting the data (usually due to an underlying data layer
     *   error).
     */
    public void setFirstname(String firstname)
        throws DiscRackBusinessException {
        try {
            myDO.setFirstname(firstname);
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error setting user's first name", ex);
        }
    }

    /**
     * Sets the lastname for the person.
     *
     * @param the lastname.
     * @exception DiscRackBusinessException if an error occurs
     *   setting the data (usually due to an underlying data layer
     *   error).
     */
    public void setLastname(String lastname)
        throws DiscRackBusinessException {
        try {
            myDO.setLastname(lastname);
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Error setting user's last name", ex);
        }
    }

    /**
     * Commits all changes to the database.
     *
     * @exception DiscRackBusinessException if an error occurs
     *   retrieving data (usually due to an underlying data layer
     *   error).
     */
    public void save() throws DiscRackBusinessException {
        try {
            this.myDO.commit();
        } catch(Exception ex) {
            throw new DiscRackBusinessException("Error saving person", ex);
        }
    }
}
