/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: PersonFactory.java,v 1.2 2004/02/01 04:17:45 christianc Exp $
 */
package org.enhydra.barracuda.discRack.biz.person;

import org.enhydra.barracuda.discRack.data.person.*;
import org.enhydra.barracuda.discRack.biz.DiscRackBusinessException;
import com.lutris.dods.builder.generator.query.*;
import com.lutris.appserver.server.Enhydra;
import com.lutris.logging.*;


/**
 * Used to find the instance of Person.
 */
public class PersonFactory {

    /**
     * The findPerson method performs a database query to
     * return a <CODE>Person</CODE> object
     * representing the row in the <CODE>person</CODE> table
     * that matches login name with the username.
     *
     * @param username, the login name of the person.
     * @return
     *    the person. null if there isn't a person associated
     *    the username
     * @exception DiscRackBusinessException
     *    if there is a problem retrieving person information.
     */
     public static Person findPerson(String username)
        throws DiscRackBusinessException {
        try {
            PersonQuery query = new PersonQuery();
            // set query.
            query.setQueryLogin(username);
            // Throw an exception if more than one user by this name is found
            query.requireUniqueInstance();

            PersonDO[] foundPerson = query.getDOArray();
            if(foundPerson.length != 0) {
                return new Person(foundPerson[0]);
            } else {
                return null;
            }
        } catch(NonUniqueQueryException ex) {
            Enhydra.getLogChannel().write(Logger.DEBUG,
                                          "Non-unique user found in database: " +
                                          ex.getMessage());
            throw new DiscRackBusinessException("More than one user found with username: " +
                                                username);
        } catch(DataObjectException ex) {
            throw new DiscRackBusinessException("Database error retrieving user: ", ex);
        } catch(QueryException ex) {
            throw new DiscRackBusinessException("Query exception retrieving user: ", ex);
        }

    }
}
