/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: DiscDOI.java,v 1.3 2004/02/01 04:17:45 christianc Exp $
 */
package org.enhydra.barracuda.discRack.data.disc;

import java.io.*;
import java.sql.*;
import java.math.*;
import com.lutris.appserver.server.*;
import com.lutris.appserver.server.sql.*;
import com.lutris.dods.builder.generator.query.*;


/**
 * Interface implemented by DiscDO.
 * Interface could also be implemented by a (hand-written) Business Layer class
 * which uses DiscDO.
 *
 * @version $Revision: 1.3 $
 * @author  ChristianC
 * @since   org.enhydra.barracuda.discRack
 */
public interface DiscDOI {


////////////////////////// data member Title


   /**
    * Get title of the Disc
    *
    * @return title of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public String getTitle ()
   throws DataObjectException;



   /**
    * Set title of the Disc
    *
    * @param title of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setTitle ( String title )
   throws DataObjectException;



////////////////////////// data member Artist


   /**
    * Get artist of the Disc
    *
    * @return artist of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public String getArtist ()
   throws DataObjectException;



   /**
    * Set artist of the Disc
    *
    * @param artist of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setArtist ( String artist )
   throws DataObjectException;



////////////////////////// data member Genre


   /**
    * Get genre of the Disc
    *
    * @return genre of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public String getGenre ()
   throws DataObjectException;



   /**
    * Set genre of the Disc
    *
    * @param genre of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setGenre ( String genre )
   throws DataObjectException;



////////////////////////// data member Owner


   /**
    * Get owner of the Disc
    *
    * @return owner of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public org.enhydra.barracuda.discRack.data.person.PersonDO getOwner ()
   throws DataObjectException;



   /**
    * Set owner of the Disc
    *
    * @param owner of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setOwner ( org.enhydra.barracuda.discRack.data.person.PersonDO owner )
   throws DataObjectException;



////////////////////////// data member IsLiked


   /**
    * Get isLiked of the Disc
    *
    * @return isLiked of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public boolean getIsLiked ()
   throws DataObjectException;



   /**
    * Set isLiked of the Disc
    *
    * @param isLiked of the Disc
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setIsLiked ( boolean isLiked )
   throws DataObjectException;



  /**
   * Inserts/Updates the DO into its table.
   *
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void save()
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Inserts/Updates the DO into its table.
   *
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   * @deprecated Use save() instead.
   */
  public void commit()
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Deletes the DO from its table.
   *
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void delete()
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;


  /**
   * Inserts/Updates the DO into its table.
   * The transaction is likely provided by the save() method of another DO
   * which references this DO.
   *
   * @param dbt The transaction object to use for this operation.
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception com.lutris.appserver.server.sql.DBRowUpdateException if a version error occurs.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void save(DBTransaction dbt)
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Inserts/Updates the DO into its table.
   * The transaction is likely provided by the commit() method of another DO
   * which references this DO.
   *
   * @param dbt The transaction object to use for this operation.
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception com.lutris.appserver.server.sql.DBRowUpdateException if a version error occurs.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   * @deprecated Use save() instead.
   */
  public void commit(DBTransaction dbt)
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Deletes the DO from its table.
   * The transaction is likely provided by the delete() method of another DO
   * which references this DO.
   *
   * @param dbt The transaction object to use for this operation.
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception com.lutris.appserver.server.sql.DBRowUpdateException if a version error occurs.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void delete(DBTransaction dbt)
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;



}
