/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: DiscDataStruct.java,v 1.3 2004/02/01 04:17:45 christianc Exp $
 */
package org.enhydra.barracuda.discRack.data.disc;

import com.lutris.appserver.server.sql.*;
import java.sql.*;
import java.math.*;
import java.io.Serializable;
import com.lutris.dods.builder.generator.dataobject.*;


/**
 * Data structure for DO class.
 * A container for data members of a DO class.
 * A DO class contains a reference to a DataStruct class.  This reference
 * can be null (a DO whose data has not yet been retrieved from the database),
 * allowing a DO object to be a lightweight placeholder until its data is needed.
 *
 * @version $Revision: 1.3 $
 * @author  ChristianC
 * @since   org.enhydra.barracuda.discRack
 */
public class DiscDataStruct implements Cloneable, Serializable {

    /**
     * A DO refers to this DataStruct.
     * readOnly is set to true when the DO is stored in its class cache.
     */
    public boolean readOnly = false;


/**
 *
 */
   public String title = null;


/**
 *
 */
   public String artist = null;


/**
 *
 */
   public String genre = null;


/**
 *Attribute describing a link to the owner of this disc.
 */
   public org.enhydra.barracuda.discRack.data.person.PersonDO owner = null;


/**
 * A flag indicating whether the user likes this disc
 */
   public boolean isLiked = false;

    /**
     * Create a copy of the guts of a DO.
     *
     * @exception DatabaseManagerException
     *       if createExisting() fails for a contained DO
     * @exception ObjectIdException
     *       if GenericDO has trouble obtaining a valid id.
     */
    public DiscDataStruct duplicate()
    throws DatabaseManagerException, ObjectIdException {
        DiscDataStruct ret = new DiscDataStruct ();




    ret.title = GenericDO.copyString(title);




    ret.artist = GenericDO.copyString(artist);




    ret.genre = GenericDO.copyString(genre);




    ret.owner = org.enhydra.barracuda.discRack.data.person.PersonDO.createCopy( owner );




    ret.isLiked = isLiked;




    return ret;
    }
}
