/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: PersonDOI.java,v 1.3 2004/02/01 04:17:45 christianc Exp $
 */
package org.enhydra.barracuda.discRack.data.person;

import java.io.*;
import java.sql.*;
import java.math.*;
import com.lutris.appserver.server.*;
import com.lutris.appserver.server.sql.*;
import com.lutris.dods.builder.generator.query.*;


/**
 * Interface implemented by PersonDO.
 * Interface could also be implemented by a (hand-written) Business Layer class
 * which uses PersonDO.
 *
 * @version $Revision: 1.3 $
 * @author  ChristianC
 * @since   org.enhydra.barracuda.discRack
 */
public interface PersonDOI {


////////////////////////// data member Login


   /**
    * Get login of the Person
    *
    * @return login of the Person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public String getLogin ()
   throws DataObjectException;



   /**
    * Set login of the Person
    *
    * @param login of the Person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setLogin ( String login )
   throws DataObjectException;



////////////////////////// data member Password


   /**
    * Get password of the Person
    *
    * @return password of the Person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public String getPassword ()
   throws DataObjectException;



   /**
    * Set password of the Person
    *
    * @param password of the Person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setPassword ( String password )
   throws DataObjectException;



////////////////////////// data member Firstname


   /**
    * Get firstname of the Person
    *
    * @return firstname of the Person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public String getFirstname ()
   throws DataObjectException;



   /**
    * Set firstname of the Person
    *
    * @param firstname of the Person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setFirstname ( String firstname )
   throws DataObjectException;



////////////////////////// data member Lastname


   /**
    * Get lastname of the Person
    *
    * @return lastname of the Person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public String getLastname ()
   throws DataObjectException;



   /**
    * Set lastname of the Person
    *
    * @param lastname of the Person
    *
    * @exception DataObjectException
    *   If the object is not found in the database.
    */
   public void setLastname ( String lastname )
   throws DataObjectException;



  /**
   * Inserts/Updates the DO into its table.
   *
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void save()
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Inserts/Updates the DO into its table.
   *
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   * @deprecated Use save() instead.
   */
  public void commit()
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Deletes the DO from its table.
   *
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void delete()
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;


  /**
   * Inserts/Updates the DO into its table.
   * The transaction is likely provided by the save() method of another DO
   * which references this DO.
   *
   * @param dbt The transaction object to use for this operation.
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception com.lutris.appserver.server.sql.DBRowUpdateException if a version error occurs.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void save(DBTransaction dbt)
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Inserts/Updates the DO into its table.
   * The transaction is likely provided by the commit() method of another DO
   * which references this DO.
   *
   * @param dbt The transaction object to use for this operation.
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception com.lutris.appserver.server.sql.DBRowUpdateException if a version error occurs.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   * @deprecated Use save() instead.
   */
  public void commit(DBTransaction dbt)
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;

  /**
   * Deletes the DO from its table.
   * The transaction is likely provided by the delete() method of another DO
   * which references this DO.
   *
   * @param dbt The transaction object to use for this operation.
   * @exception com.lutris.appserver.server.sql.DatabaseManagerException if a Transaction can not be created.
   * @exception com.lutris.appserver.server.sql.DBRowUpdateException if a version error occurs.
   * @exception RefAssertionException thrown by okTo method.
   * @exception java.sql.SQLException if any SQL errors occur.
   */
  public void delete(DBTransaction dbt)
  throws SQLException, DatabaseManagerException, DataObjectException, RefAssertionException, DBRowUpdateException, QueryException;



}
