/*
 * Copyright (C) 2003  Christian Cryder [christianc@granitepeaks.com]
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: LoginServices.java,v 1.6 2004/02/01 04:17:45 christianc Exp $
 */
package org.enhydra.barracuda.discRack.pres.services;

import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;

import org.enhydra.barracuda.core.event.*;
import org.enhydra.barracuda.plankton.data.*;
import org.enhydra.barracuda.core.util.http.*;

import org.enhydra.barracuda.discRack.biz.person.Person;

/**
 * This class provides basic Login services. You can see whether
 * the user is logged in, get the current user (Person), log them in
 * or out.
 */
public class LoginServices {

    //private constants
    private static String PERSON = LoginServices.class.getName()+".Person";

    /**
     * See if the current user is actually logged in
     */
    public static boolean isLoggedIn(HttpSession session) {
//Debug.println (new LoginServices(),0,"isLoggedIn:"+session.getAttribute(PERSON));
        return (session.getAttribute(PERSON)!=null);
    }

    /**
     * Get the Person record for the current user
     */
    public static Person getCurrentUser(HttpSession session) {
        return (Person) session.getAttribute(PERSON);
    }

    /**
     * Actually log a user in by storing the Person account in the
     * session
     */
    public static void logIn(HttpSession session, Person person) {
//Debug.println (new LoginServices(),0,"logging in:"+person);
        session.setAttribute(PERSON, person);
    }

    /**
     * Actually log a user out by removing the Person account from the
     * session
     */
    public static void logOut(HttpSession session) {
//Debug.println (new LoginServices(),0,"logging out");
        session.removeAttribute(PERSON);
    }
}
